# Description
This is a responses API agent that is intended to be used when any required tool execution results are generated by simulation.

# Licensing information
Code: Apache 2.0<br>
Data: N/A

Dependencies
- nemo_gym: Apache 2.0
